@@ -1,6 +1,6 @@
 #!/usr/bin/perl -s 
 
-use lib '.';
+use lib './lib';
 
 use Tk;                   #LOAD TK STUFF
 use Tk::JFileDialog;
